@@ -1,4 +1,4 @@
-specialize_for!("avx2", simd_abstraction::AVX2);
+specialize_for!("avx2", simd_abstraction::x86::AVX2);
 
 #[cfg(target_feature = "avx2")]
 #[test]
