@@ -1,5 +1,4 @@
 #![cfg_attr(not(any(feature = "std", test)), no_std)]
-
 #![deny(clippy::all, clippy::cargo)]
 #![allow(clippy::missing_safety_doc)] // TODO
 
@@ -16,13 +15,11 @@ macro_rules! item_group {
 //
 //
 
-#[cfg(test)]
-mod tests;
-
 mod polyfill;
 
 #[macro_use]
 mod generic;
+pub mod fallback;
 
 #[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
 item_group! {
@@ -31,11 +28,17 @@ item_group! {
 }
 
 mod auto;
-
-pub mod fallback;
-
 pub use self::auto::*;
 
+#[cfg(feature = "uuid")]
+item_group! {
+    mod ext;
+    pub use self::ext::UuidExt;
+}
+
+#[cfg(test)]
+mod tests;
+
 //
 //
 //
@@ -58,3 +61,5 @@ impl fmt::Display for Error {
 
 #[cfg(feature = "std")]
 impl std::error::Error for Error {}
+
+pub use simd_abstraction::generic::hex::AsciiCase;
