@@ -15,7 +15,9 @@ mod x86 {
     #[cfg(target_arch = "x86_64")]
     use core::arch::x86_64::*;
 
-    unsafe impl SIMD256Ext for simd_abstraction::AVX2 {
+    use simd_abstraction::x86::*;
+
+    unsafe impl SIMD256Ext for AVX2 {
         #[inline(always)]
         fn i16x16_write_index7(self, a: Self::V256, x: i16) -> Self::V256 {
             unsafe { _mm256_insert_epi16::<7>(a, x) }
@@ -27,7 +29,7 @@ mod x86 {
         }
     }
 
-    unsafe impl SIMD256Ext for simd_abstraction::SSE41 {
+    unsafe impl SIMD256Ext for SSE41 {
         #[inline(always)]
         fn i16x16_write_index7(self, a: Self::V256, x: i16) -> Self::V256 {
             unsafe { (_mm_insert_epi16::<7>(a.0, x as i32), a.1) }
