@@ -1,4 +1,4 @@
-specialize_for!("sse4.1", simd_abstraction::SSE41);
+specialize_for!("sse4.1", simd_abstraction::x86::SSE41);
 
 #[cfg(target_feature = "sse4.1")]
 #[test]
